extends CharacterBody2D


const SPEED = 300.0
const JUMP_VELOCITY = -400.0

# Get the gravity from the project settings to be synced with RigidDynamicBody nodes.
var gravity = ProjectSettings.get_setting("physics/2d/default_gravity")

var direction := 0.0
var jumping := false


@rpc(any_peer)
func set_controls(dir: float, jump: bool):
	if str(multiplayer.get_remote_sender_id()) != str(name):
		return
	direction = clamp(dir, -1, 1)
	jumping = jump


func update_controls():
	if not multiplayer.has_multiplayer_peer() or str(name) != str(multiplayer.get_unique_id()):
		return

	direction = Input.get_axis("move_left", "move_right")
	jumping = Input.is_action_just_pressed("ui_accept")

	# TODO handle RPC visibility internally, sync controls only to server for now.
	if not multiplayer.is_server():
		set_controls.rpc_id(1, direction, jumping)


func _physics_process(delta):
	update_controls()

	# Add the gravity.
	if not is_on_floor():
		velocity.y += gravity * delta

	# Handle Jump.
	if jumping and is_on_floor():
		velocity.y = JUMP_VELOCITY

	# Get the last input direction and handle the movement/deceleration.
	if direction:
		velocity.x = direction * SPEED
	else:
		velocity.x = move_toward(velocity.x, 0, SPEED)

	move_and_slide()
